16.128. cdist-type__postgres_conf(7) — cdist 6.9.8 documentation

# 16.128. cdist-type__postgres_conf(7)

## 16.128.1. NAME

cdist-type__postgres_conf - Alter PostgreSQL configuration

## 16.128.2. DESCRIPTION

Configure a running PostgreSQL server using `ALTER SYSTEM`.

## 16.128.3. REQUIRED PARAMETERS

value

  The value to set (can be omitted if `--state` is set to `absent`).

## 16.128.4. OPTIONAL PARAMETERS

state

  `present` or `absent`. Defaults to `present`.

## 16.128.5. BOOLEAN PARAMETERS

None.

## 16.128.6. EXAMPLES

    # set timezone
    __postgres_conf timezone --value Europe/Zurich

    # reset maximum number of concurrent connections to default (normally 100)
    __postgres_conf max_connections --state absent

## 16.128.7. SEE ALSO

None.

## 16.128.8. AUTHORS

Beni Ruef (bernhard.ruef--@--ssrq-sds-fds.ch) Dennis Camera (dennis.camera--@--ssrq-sds-fds.ch)

## 16.128.9. COPYING

Copyright (C) 2019-2021 SSRQ (www.ssrq-sds-fds.ch). You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.